# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List
from datetime import datetime

from .._models import BaseModel

__all__ = ["SchemaListResponse", "Schema"]


class Schema(BaseModel):
    created_at: datetime

    schema_data: Dict[str, object]

    schema_description: str

    schema_id: str

    schema_name: str

    updated_at: datetime

    user_id: str


class SchemaListResponse(BaseModel):
    schemas: List[Schema]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Optional
from datetime import datetime

from .._compat import PYDANTIC_V2
from .._models import BaseModel

__all__ = ["DatasliceListResponse", "Dataslice"]


class Dataslice(BaseModel):
    dataslice_id: str

    dataslice_name: str

    last_updated: datetime

    status: str

    condition: Optional[List[Dict[str, object]]] = None

    condition_new: Optional["ConditionOutput"] = None

    data_points: Optional[int] = None

    description: Optional[str] = None

    export_collection_name: Optional[str] = None

    graph_id: Optional[str] = None

    latest_graph: Optional[Dict[str, object]] = None

    vector_db_config: Optional[Dict[str, object]] = None


class DatasliceListResponse(BaseModel):
    dataslices: List[Dataslice]


from .condition_output import ConditionOutput

if PYDANTIC_V2:
    DatasliceListResponse.model_rebuild()
    Dataslice.model_rebuild()
else:
    DatasliceListResponse.update_forward_refs()  # type: ignore
    Dataslice.update_forward_refs()  # type: ignore



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Optional

import httpx

from ..types import classify_classify_files_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.classify_classify_files_response import ClassifyClassifyFilesResponse

__all__ = ["ClassifyResource", "AsyncClassifyResource"]


class ClassifyResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ClassifyResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return ClassifyResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ClassifyResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return ClassifyResourceWithStreamingResponse(self)

    def classify_files(
        self,
        *,
        data_connector_name: str,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        file_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        hierarchy_data: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        hierarchy_name: Optional[str] | NotGiven = NOT_GIVEN,
        job_id: Optional[str] | NotGiven = NOT_GIVEN,
        llm_profile_name: Optional[str] | NotGiven = NOT_GIVEN,
        overwrite: bool | NotGiven = NOT_GIVEN,
        soft_run: bool | NotGiven = NOT_GIVEN,
        tag_datas: Optional[Dict[str, classify_classify_files_params.TagDatas]] | NotGiven = NOT_GIVEN,
        tag_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ClassifyClassifyFilesResponse:
        """
        Classify files specified in the request with the provided tags

        Attributes:

            data_connector_name: The name of the vdb profile to use for classification.
            llm_profile_name: The name of the llm profile to use for classification.
            file_names: The names of the files to classify.
            tag_names: The names of the tags to use for classification if tag datas are not provided.
            tag_datas: The data of the tags to use for classification.
            overwrite: Whether to overwrite existing tags.
            hierarchy_name: The name of the graph to use for classification if hierarchy data is not provided.
            hierarchy_data: The data of the graph to use for classification.
            dataslice_id: The id of the dataslice to use for classification file filtering.
            soft_run: If true, the classification will not save to Deasy and will attempt to return the results.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/classify",
            body=maybe_transform(
                {
                    "data_connector_name": data_connector_name,
                    "dataslice_id": dataslice_id,
                    "file_names": file_names,
                    "hierarchy_data": hierarchy_data,
                    "hierarchy_name": hierarchy_name,
                    "job_id": job_id,
                    "llm_profile_name": llm_profile_name,
                    "overwrite": overwrite,
                    "soft_run": soft_run,
                    "tag_datas": tag_datas,
                    "tag_names": tag_names,
                },
                classify_classify_files_params.ClassifyClassifyFilesParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ClassifyClassifyFilesResponse,
        )


class AsyncClassifyResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncClassifyResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return AsyncClassifyResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncClassifyResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return AsyncClassifyResourceWithStreamingResponse(self)

    async def classify_files(
        self,
        *,
        data_connector_name: str,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        file_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        hierarchy_data: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        hierarchy_name: Optional[str] | NotGiven = NOT_GIVEN,
        job_id: Optional[str] | NotGiven = NOT_GIVEN,
        llm_profile_name: Optional[str] | NotGiven = NOT_GIVEN,
        overwrite: bool | NotGiven = NOT_GIVEN,
        soft_run: bool | NotGiven = NOT_GIVEN,
        tag_datas: Optional[Dict[str, classify_classify_files_params.TagDatas]] | NotGiven = NOT_GIVEN,
        tag_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> ClassifyClassifyFilesResponse:
        """
        Classify files specified in the request with the provided tags

        Attributes:

            data_connector_name: The name of the vdb profile to use for classification.
            llm_profile_name: The name of the llm profile to use for classification.
            file_names: The names of the files to classify.
            tag_names: The names of the tags to use for classification if tag datas are not provided.
            tag_datas: The data of the tags to use for classification.
            overwrite: Whether to overwrite existing tags.
            hierarchy_name: The name of the graph to use for classification if hierarchy data is not provided.
            hierarchy_data: The data of the graph to use for classification.
            dataslice_id: The id of the dataslice to use for classification file filtering.
            soft_run: If true, the classification will not save to Deasy and will attempt to return the results.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/classify",
            body=await async_maybe_transform(
                {
                    "data_connector_name": data_connector_name,
                    "dataslice_id": dataslice_id,
                    "file_names": file_names,
                    "hierarchy_data": hierarchy_data,
                    "hierarchy_name": hierarchy_name,
                    "job_id": job_id,
                    "llm_profile_name": llm_profile_name,
                    "overwrite": overwrite,
                    "soft_run": soft_run,
                    "tag_datas": tag_datas,
                    "tag_names": tag_names,
                },
                classify_classify_files_params.ClassifyClassifyFilesParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ClassifyClassifyFilesResponse,
        )


class ClassifyResourceWithRawResponse:
    def __init__(self, classify: ClassifyResource) -> None:
        self._classify = classify

        self.classify_files = to_raw_response_wrapper(
            classify.classify_files,
        )


class AsyncClassifyResourceWithRawResponse:
    def __init__(self, classify: AsyncClassifyResource) -> None:
        self._classify = classify

        self.classify_files = async_to_raw_response_wrapper(
            classify.classify_files,
        )


class ClassifyResourceWithStreamingResponse:
    def __init__(self, classify: ClassifyResource) -> None:
        self._classify = classify

        self.classify_files = to_streamed_response_wrapper(
            classify.classify_files,
        )


class AsyncClassifyResourceWithStreamingResponse:
    def __init__(self, classify: AsyncClassifyResource) -> None:
        self._classify = classify

        self.classify_files = async_to_streamed_response_wrapper(
            classify.classify_files,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["PrepareDataCreateParams"]


class PrepareDataCreateParams(TypedDict, total=False):
    data_connector_name: Required[str]

    llm_profile_name: Optional[str]

    total_data_sets: Optional[int]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from .._models import BaseModel
from .deasy_tag import DeasyTag

__all__ = ["TagListResponse"]


class TagListResponse(BaseModel):
    tags: List[DeasyTag]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import (
    tag_create_params,
    tag_delete_params,
    tag_update_params,
    tag_upsert_params,
    tag_get_delete_stats_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.tag_response import TagResponse
from ..types.tag_list_response import TagListResponse
from ..types.tag_create_response import TagCreateResponse
from ..types.tag_upsert_response import TagUpsertResponse
from ..types.tag_get_delete_stats_response import TagGetDeleteStatsResponse

__all__ = ["TagsResource", "AsyncTagsResource"]


class TagsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> TagsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return TagsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> TagsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return TagsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        tag_data: tag_create_params.TagData,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TagCreateResponse:
        """
        Create a new tag

        Attributes:

            tag_data: The tag data to create the tag with.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/tags/create",
            body=maybe_transform({"tag_data": tag_data}, tag_create_params.TagCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagCreateResponse,
        )

    def update(
        self,
        *,
        tag_data: tag_update_params.TagData,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TagResponse:
        """
        Update an existing tag

        Attributes:

            tag_data: The tag data to update the tag with.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._put(
            "/tags/update",
            body=maybe_transform({"tag_data": tag_data}, tag_update_params.TagUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagResponse,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TagListResponse:
        """Lists all tags"""
        return self._get(
            "/tags/list",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagListResponse,
        )

    def delete(
        self,
        *,
        tag_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TagResponse:
        """
        Delete a tag

        Attributes:

            tag_name: The name of the tag to delete.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._delete(
            "/tags/delete",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"tag_name": tag_name}, tag_delete_params.TagDeleteParams),
            ),
            cast_to=TagResponse,
        )

    def get_delete_stats(
        self,
        *,
        tag_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TagGetDeleteStatsResponse:
        """
        Get tag delete stats

        Attributes:

            tag_name: The name of the tag to get the delete stats for.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/tags/delete_stats",
            body=maybe_transform({"tag_name": tag_name}, tag_get_delete_stats_params.TagGetDeleteStatsParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagGetDeleteStatsResponse,
        )

    def upsert(
        self,
        *,
        tag_data: tag_upsert_params.TagData,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TagUpsertResponse:
        """
        Upsert a tag

        Attributes:

            tag_data: The tag data to upsert the tag with.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/tags/upsert",
            body=maybe_transform({"tag_data": tag_data}, tag_upsert_params.TagUpsertParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagUpsertResponse,
        )


class AsyncTagsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncTagsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return AsyncTagsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncTagsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return AsyncTagsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        tag_data: tag_create_params.TagData,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TagCreateResponse:
        """
        Create a new tag

        Attributes:

            tag_data: The tag data to create the tag with.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/tags/create",
            body=await async_maybe_transform({"tag_data": tag_data}, tag_create_params.TagCreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagCreateResponse,
        )

    async def update(
        self,
        *,
        tag_data: tag_update_params.TagData,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TagResponse:
        """
        Update an existing tag

        Attributes:

            tag_data: The tag data to update the tag with.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._put(
            "/tags/update",
            body=await async_maybe_transform({"tag_data": tag_data}, tag_update_params.TagUpdateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagResponse,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TagListResponse:
        """Lists all tags"""
        return await self._get(
            "/tags/list",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagListResponse,
        )

    async def delete(
        self,
        *,
        tag_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TagResponse:
        """
        Delete a tag

        Attributes:

            tag_name: The name of the tag to delete.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._delete(
            "/tags/delete",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"tag_name": tag_name}, tag_delete_params.TagDeleteParams),
            ),
            cast_to=TagResponse,
        )

    async def get_delete_stats(
        self,
        *,
        tag_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TagGetDeleteStatsResponse:
        """
        Get tag delete stats

        Attributes:

            tag_name: The name of the tag to get the delete stats for.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/tags/delete_stats",
            body=await async_maybe_transform(
                {"tag_name": tag_name}, tag_get_delete_stats_params.TagGetDeleteStatsParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagGetDeleteStatsResponse,
        )

    async def upsert(
        self,
        *,
        tag_data: tag_upsert_params.TagData,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> TagUpsertResponse:
        """
        Upsert a tag

        Attributes:

            tag_data: The tag data to upsert the tag with.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/tags/upsert",
            body=await async_maybe_transform({"tag_data": tag_data}, tag_upsert_params.TagUpsertParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=TagUpsertResponse,
        )


class TagsResourceWithRawResponse:
    def __init__(self, tags: TagsResource) -> None:
        self._tags = tags

        self.create = to_raw_response_wrapper(
            tags.create,
        )
        self.update = to_raw_response_wrapper(
            tags.update,
        )
        self.list = to_raw_response_wrapper(
            tags.list,
        )
        self.delete = to_raw_response_wrapper(
            tags.delete,
        )
        self.get_delete_stats = to_raw_response_wrapper(
            tags.get_delete_stats,
        )
        self.upsert = to_raw_response_wrapper(
            tags.upsert,
        )


class AsyncTagsResourceWithRawResponse:
    def __init__(self, tags: AsyncTagsResource) -> None:
        self._tags = tags

        self.create = async_to_raw_response_wrapper(
            tags.create,
        )
        self.update = async_to_raw_response_wrapper(
            tags.update,
        )
        self.list = async_to_raw_response_wrapper(
            tags.list,
        )
        self.delete = async_to_raw_response_wrapper(
            tags.delete,
        )
        self.get_delete_stats = async_to_raw_response_wrapper(
            tags.get_delete_stats,
        )
        self.upsert = async_to_raw_response_wrapper(
            tags.upsert,
        )


class TagsResourceWithStreamingResponse:
    def __init__(self, tags: TagsResource) -> None:
        self._tags = tags

        self.create = to_streamed_response_wrapper(
            tags.create,
        )
        self.update = to_streamed_response_wrapper(
            tags.update,
        )
        self.list = to_streamed_response_wrapper(
            tags.list,
        )
        self.delete = to_streamed_response_wrapper(
            tags.delete,
        )
        self.get_delete_stats = to_streamed_response_wrapper(
            tags.get_delete_stats,
        )
        self.upsert = to_streamed_response_wrapper(
            tags.upsert,
        )


class AsyncTagsResourceWithStreamingResponse:
    def __init__(self, tags: AsyncTagsResource) -> None:
        self._tags = tags

        self.create = async_to_streamed_response_wrapper(
            tags.create,
        )
        self.update = async_to_streamed_response_wrapper(
            tags.update,
        )
        self.list = async_to_streamed_response_wrapper(
            tags.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            tags.delete,
        )
        self.get_delete_stats = async_to_streamed_response_wrapper(
            tags.get_delete_stats,
        )
        self.upsert = async_to_streamed_response_wrapper(
            tags.upsert,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional

import httpx

from ..types import suggest_description_create_params
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.suggest_description_create_response import SuggestDescriptionCreateResponse

__all__ = ["SuggestDescriptionResource", "AsyncSuggestDescriptionResource"]


class SuggestDescriptionResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SuggestDescriptionResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return SuggestDescriptionResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SuggestDescriptionResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return SuggestDescriptionResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        data_connector_name: str,
        tag_name: str,
        available_values: Optional[List[str]] | NotGiven = NOT_GIVEN,
        context: Optional[str] | NotGiven = NOT_GIVEN,
        current_description: Optional[str] | NotGiven = NOT_GIVEN,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        llm_profile_name: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SuggestDescriptionCreateResponse:
        """
        Suggest a description for a tag based on context and vector DB content

        Attributes:

            data_connector_name: The name of the vdb profile to include in the dataslice.
            llm_profile_name: The name of the llm profile to use for the suggestion.
            tag_name: The name of the tag to suggest a description for.
            context: The context to suggest a description for the tag.
            current_description: The current description of the tag.
            available_values: The available values for the tag.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/suggest_description",
            body=maybe_transform(
                {
                    "data_connector_name": data_connector_name,
                    "tag_name": tag_name,
                    "available_values": available_values,
                    "context": context,
                    "current_description": current_description,
                    "dataslice_id": dataslice_id,
                    "llm_profile_name": llm_profile_name,
                },
                suggest_description_create_params.SuggestDescriptionCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SuggestDescriptionCreateResponse,
        )


class AsyncSuggestDescriptionResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSuggestDescriptionResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return AsyncSuggestDescriptionResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSuggestDescriptionResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return AsyncSuggestDescriptionResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        data_connector_name: str,
        tag_name: str,
        available_values: Optional[List[str]] | NotGiven = NOT_GIVEN,
        context: Optional[str] | NotGiven = NOT_GIVEN,
        current_description: Optional[str] | NotGiven = NOT_GIVEN,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        llm_profile_name: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> SuggestDescriptionCreateResponse:
        """
        Suggest a description for a tag based on context and vector DB content

        Attributes:

            data_connector_name: The name of the vdb profile to include in the dataslice.
            llm_profile_name: The name of the llm profile to use for the suggestion.
            tag_name: The name of the tag to suggest a description for.
            context: The context to suggest a description for the tag.
            current_description: The current description of the tag.
            available_values: The available values for the tag.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/suggest_description",
            body=await async_maybe_transform(
                {
                    "data_connector_name": data_connector_name,
                    "tag_name": tag_name,
                    "available_values": available_values,
                    "context": context,
                    "current_description": current_description,
                    "dataslice_id": dataslice_id,
                    "llm_profile_name": llm_profile_name,
                },
                suggest_description_create_params.SuggestDescriptionCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SuggestDescriptionCreateResponse,
        )


class SuggestDescriptionResourceWithRawResponse:
    def __init__(self, suggest_description: SuggestDescriptionResource) -> None:
        self._suggest_description = suggest_description

        self.create = to_raw_response_wrapper(
            suggest_description.create,
        )


class AsyncSuggestDescriptionResourceWithRawResponse:
    def __init__(self, suggest_description: AsyncSuggestDescriptionResource) -> None:
        self._suggest_description = suggest_description

        self.create = async_to_raw_response_wrapper(
            suggest_description.create,
        )


class SuggestDescriptionResourceWithStreamingResponse:
    def __init__(self, suggest_description: SuggestDescriptionResource) -> None:
        self._suggest_description = suggest_description

        self.create = to_streamed_response_wrapper(
            suggest_description.create,
        )


class AsyncSuggestDescriptionResourceWithStreamingResponse:
    def __init__(self, suggest_description: AsyncSuggestDescriptionResource) -> None:
        self._suggest_description = suggest_description

        self.create = async_to_streamed_response_wrapper(
            suggest_description.create,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["SuggestSchemaCreateResponse", "SuggestedTags"]


class SuggestedTags(BaseModel):
    name: str

    output_type: str

    available_values: Optional[List[str]] = None

    date_format: Optional[str] = None

    description: Optional[str] = None

    examples: Optional[List[Union[Dict[str, object], str]]] = None

    max_values: Optional[int] = FieldInfo(alias="maxValues", default=None)

    tag_id: Optional[str] = None

    tuned: Optional[int] = None


class SuggestSchemaCreateResponse(BaseModel):
    suggestion: Dict[str, object]

    message: Optional[str] = None

    status_code: Optional[int] = None

    suggested_tags: Optional[Dict[str, SuggestedTags]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Literal

import httpx

from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.dataslice import export_export_metadata_params

__all__ = ["ExportResource", "AsyncExportResource"]


class ExportResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ExportResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return ExportResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ExportResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return ExportResourceWithStreamingResponse(self)

    def export_metadata(
        self,
        *,
        data_connector_name: str,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        export_file_level: bool | NotGiven = NOT_GIVEN,
        export_format: Optional[Literal["json", "csv"]] | NotGiven = NOT_GIVEN,
        selected_metadata_fields: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Export file-level/chunk-level metadata for a use case

        Attributes:

            data_connector_name: The name of the vdb profile to export metadata from.
            dataslice_id: The id of the dataslice to export metadata from.
            export_file_level: Whether to export file-level metadata or chunk-level metadata.
            export_format: The format to export the metadata in, JSON or CSV.
            selected_metadata_fields: The metadata fields to include in the export.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/dataslice/export/metadata",
            body=maybe_transform(
                {
                    "data_connector_name": data_connector_name,
                    "dataslice_id": dataslice_id,
                    "export_file_level": export_file_level,
                    "export_format": export_format,
                    "selected_metadata_fields": selected_metadata_fields,
                },
                export_export_metadata_params.ExportExportMetadataParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class AsyncExportResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncExportResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return AsyncExportResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncExportResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return AsyncExportResourceWithStreamingResponse(self)

    async def export_metadata(
        self,
        *,
        data_connector_name: str,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        export_file_level: bool | NotGiven = NOT_GIVEN,
        export_format: Optional[Literal["json", "csv"]] | NotGiven = NOT_GIVEN,
        selected_metadata_fields: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> object:
        """
        Export file-level/chunk-level metadata for a use case

        Attributes:

            data_connector_name: The name of the vdb profile to export metadata from.
            dataslice_id: The id of the dataslice to export metadata from.
            export_file_level: Whether to export file-level metadata or chunk-level metadata.
            export_format: The format to export the metadata in, JSON or CSV.
            selected_metadata_fields: The metadata fields to include in the export.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/dataslice/export/metadata",
            body=await async_maybe_transform(
                {
                    "data_connector_name": data_connector_name,
                    "dataslice_id": dataslice_id,
                    "export_file_level": export_file_level,
                    "export_format": export_format,
                    "selected_metadata_fields": selected_metadata_fields,
                },
                export_export_metadata_params.ExportExportMetadataParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=object,
        )


class ExportResourceWithRawResponse:
    def __init__(self, export: ExportResource) -> None:
        self._export = export

        self.export_metadata = to_raw_response_wrapper(
            export.export_metadata,
        )


class AsyncExportResourceWithRawResponse:
    def __init__(self, export: AsyncExportResource) -> None:
        self._export = export

        self.export_metadata = async_to_raw_response_wrapper(
            export.export_metadata,
        )


class ExportResourceWithStreamingResponse:
    def __init__(self, export: ExportResource) -> None:
        self._export = export

        self.export_metadata = to_streamed_response_wrapper(
            export.export_metadata,
        )


class AsyncExportResourceWithStreamingResponse:
    def __init__(self, export: AsyncExportResource) -> None:
        self._export = export

        self.export_metadata = async_to_streamed_response_wrapper(
            export.export_metadata,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Optional
from typing_extensions import Literal

from .._compat import PYDANTIC_V2
from .._models import BaseModel

__all__ = ["ConditionOutput", "Tag"]


class Tag(BaseModel):
    name: str

    values: List[Union[str, float]]

    operator: Optional[str] = None


class ConditionOutput(BaseModel):
    children: Optional[List["ConditionOutput"]] = None

    condition: Optional[Literal["AND", "OR"]] = None

    tag: Optional[Tag] = None


if PYDANTIC_V2:
    ConditionOutput.model_rebuild()
    Tag.model_rebuild()
else:
    ConditionOutput.update_forward_refs()  # type: ignore
    Tag.update_forward_refs()  # type: ignore



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List

from .._models import BaseModel

__all__ = ["DatasliceGetMetricsResponse"]


class DatasliceGetMetricsResponse(BaseModel):
    metadata_tag_counts_distribution: Dict[str, List[float]]

    total_file_count: int

    total_metadata_tags: int

    total_node_count: int

    unique_metadata_tags: int



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Required, TypedDict

__all__ = ["MetadataListParams"]


class MetadataListParams(TypedDict, total=False):
    data_connector_name: Required[str]

    conditions: Optional["ConditionInputParam"]

    dataslice_id: Optional[str]

    include_chunk_level: Optional[bool]

    tag_names: Optional[List[str]]


from .condition_input_param import ConditionInputParam



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .export_export_metadata_params import ExportExportMetadataParams as ExportExportMetadataParams



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["SuggestDescriptionCreateResponse"]


class SuggestDescriptionCreateResponse(BaseModel):
    suggestion: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Required, TypedDict

__all__ = ["SuggestDescriptionCreateParams"]


class SuggestDescriptionCreateParams(TypedDict, total=False):
    data_connector_name: Required[str]

    tag_name: Required[str]

    available_values: Optional[List[str]]

    context: Optional[str]

    current_description: Optional[str]

    dataslice_id: Optional[str]

    llm_profile_name: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from deasy_client import Deasy, AsyncDeasy
from deasy_client.types import (
    SchemaListResponse,
    SchemaOperationResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSchema:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: Deasy) -> None:
        schema = client.schema.create(
            schema_name="schema_name",
        )
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: Deasy) -> None:
        schema = client.schema.create(
            schema_name="schema_name",
            schema_data={"foo": "bar"},
            schema_description="schema_description",
        )
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: Deasy) -> None:
        response = client.schema.with_raw_response.create(
            schema_name="schema_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        schema = response.parse()
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: Deasy) -> None:
        with client.schema.with_streaming_response.create(
            schema_name="schema_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            schema = response.parse()
            assert_matches_type(SchemaOperationResponse, schema, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_update(self, client: Deasy) -> None:
        schema = client.schema.update(
            schema_name="schema_name",
        )
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update_with_all_params(self, client: Deasy) -> None:
        schema = client.schema.update(
            schema_name="schema_name",
            schema_data={"foo": "bar"},
            schema_description="schema_description",
        )
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update(self, client: Deasy) -> None:
        response = client.schema.with_raw_response.update(
            schema_name="schema_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        schema = response.parse()
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update(self, client: Deasy) -> None:
        with client.schema.with_streaming_response.update(
            schema_name="schema_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            schema = response.parse()
            assert_matches_type(SchemaOperationResponse, schema, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_list(self, client: Deasy) -> None:
        schema = client.schema.list()
        assert_matches_type(SchemaListResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_list_with_all_params(self, client: Deasy) -> None:
        schema = client.schema.list(
            schema_ids=["string"],
        )
        assert_matches_type(SchemaListResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list(self, client: Deasy) -> None:
        response = client.schema.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        schema = response.parse()
        assert_matches_type(SchemaListResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list(self, client: Deasy) -> None:
        with client.schema.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            schema = response.parse()
            assert_matches_type(SchemaListResponse, schema, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_delete(self, client: Deasy) -> None:
        schema = client.schema.delete(
            schema_name="schema_name",
        )
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_delete(self, client: Deasy) -> None:
        response = client.schema.with_raw_response.delete(
            schema_name="schema_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        schema = response.parse()
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_delete(self, client: Deasy) -> None:
        with client.schema.with_streaming_response.delete(
            schema_name="schema_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            schema = response.parse()
            assert_matches_type(SchemaOperationResponse, schema, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_upsert(self, client: Deasy) -> None:
        schema = client.schema.upsert(
            schema_name="schema_name",
        )
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_upsert_with_all_params(self, client: Deasy) -> None:
        schema = client.schema.upsert(
            schema_name="schema_name",
            new_schema_name="new_schema_name",
            schema_data={"foo": "bar"},
            schema_description="schema_description",
        )
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_upsert(self, client: Deasy) -> None:
        response = client.schema.with_raw_response.upsert(
            schema_name="schema_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        schema = response.parse()
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_upsert(self, client: Deasy) -> None:
        with client.schema.with_streaming_response.upsert(
            schema_name="schema_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            schema = response.parse()
            assert_matches_type(SchemaOperationResponse, schema, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncSchema:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncDeasy) -> None:
        schema = await async_client.schema.create(
            schema_name="schema_name",
        )
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncDeasy) -> None:
        schema = await async_client.schema.create(
            schema_name="schema_name",
            schema_data={"foo": "bar"},
            schema_description="schema_description",
        )
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncDeasy) -> None:
        response = await async_client.schema.with_raw_response.create(
            schema_name="schema_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        schema = await response.parse()
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncDeasy) -> None:
        async with async_client.schema.with_streaming_response.create(
            schema_name="schema_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            schema = await response.parse()
            assert_matches_type(SchemaOperationResponse, schema, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_update(self, async_client: AsyncDeasy) -> None:
        schema = await async_client.schema.update(
            schema_name="schema_name",
        )
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncDeasy) -> None:
        schema = await async_client.schema.update(
            schema_name="schema_name",
            schema_data={"foo": "bar"},
            schema_description="schema_description",
        )
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncDeasy) -> None:
        response = await async_client.schema.with_raw_response.update(
            schema_name="schema_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        schema = await response.parse()
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncDeasy) -> None:
        async with async_client.schema.with_streaming_response.update(
            schema_name="schema_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            schema = await response.parse()
            assert_matches_type(SchemaOperationResponse, schema, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_list(self, async_client: AsyncDeasy) -> None:
        schema = await async_client.schema.list()
        assert_matches_type(SchemaListResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncDeasy) -> None:
        schema = await async_client.schema.list(
            schema_ids=["string"],
        )
        assert_matches_type(SchemaListResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncDeasy) -> None:
        response = await async_client.schema.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        schema = await response.parse()
        assert_matches_type(SchemaListResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncDeasy) -> None:
        async with async_client.schema.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            schema = await response.parse()
            assert_matches_type(SchemaListResponse, schema, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete(self, async_client: AsyncDeasy) -> None:
        schema = await async_client.schema.delete(
            schema_name="schema_name",
        )
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncDeasy) -> None:
        response = await async_client.schema.with_raw_response.delete(
            schema_name="schema_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        schema = await response.parse()
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncDeasy) -> None:
        async with async_client.schema.with_streaming_response.delete(
            schema_name="schema_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            schema = await response.parse()
            assert_matches_type(SchemaOperationResponse, schema, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_upsert(self, async_client: AsyncDeasy) -> None:
        schema = await async_client.schema.upsert(
            schema_name="schema_name",
        )
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_upsert_with_all_params(self, async_client: AsyncDeasy) -> None:
        schema = await async_client.schema.upsert(
            schema_name="schema_name",
            new_schema_name="new_schema_name",
            schema_data={"foo": "bar"},
            schema_description="schema_description",
        )
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_upsert(self, async_client: AsyncDeasy) -> None:
        response = await async_client.schema.with_raw_response.upsert(
            schema_name="schema_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        schema = await response.parse()
        assert_matches_type(SchemaOperationResponse, schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_upsert(self, async_client: AsyncDeasy) -> None:
        async with async_client.schema.with_streaming_response.upsert(
            schema_name="schema_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            schema = await response.parse()
            assert_matches_type(SchemaOperationResponse, schema, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["TagCreateResponse"]


class TagCreateResponse(BaseModel):
    tag_name: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from deasy_client import Deasy, AsyncDeasy
from deasy_client.types import (
    ListVdbConnector,
    ConnectorResponse,
    VdbConnectorGetDeleteStatsResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestVdbConnector:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: Deasy) -> None:
        vdb_connector = client.vdb_connector.create(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
            },
            connector_name="connector_name",
        )
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: Deasy) -> None:
        vdb_connector = client.vdb_connector.create(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
                "filename_key": "filename_key",
                "index_info": {
                    "found_indexes": ["string"],
                    "total_indexes_found": 0,
                },
                "text_key": "text_key",
                "type": "PSQLVectorDBManager",
            },
            connector_name="connector_name",
        )
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: Deasy) -> None:
        response = client.vdb_connector.with_raw_response.create(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
            },
            connector_name="connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vdb_connector = response.parse()
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: Deasy) -> None:
        with client.vdb_connector.with_streaming_response.create(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
            },
            connector_name="connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vdb_connector = response.parse()
            assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_update(self, client: Deasy) -> None:
        vdb_connector = client.vdb_connector.update(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
            },
            connector_name="connector_name",
        )
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update_with_all_params(self, client: Deasy) -> None:
        vdb_connector = client.vdb_connector.update(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
                "filename_key": "filename_key",
                "index_info": {
                    "found_indexes": ["string"],
                    "total_indexes_found": 0,
                },
                "text_key": "text_key",
                "type": "PSQLVectorDBManager",
            },
            connector_name="connector_name",
        )
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update(self, client: Deasy) -> None:
        response = client.vdb_connector.with_raw_response.update(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
            },
            connector_name="connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vdb_connector = response.parse()
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update(self, client: Deasy) -> None:
        with client.vdb_connector.with_streaming_response.update(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
            },
            connector_name="connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vdb_connector = response.parse()
            assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_list(self, client: Deasy) -> None:
        vdb_connector = client.vdb_connector.list()
        assert_matches_type(ListVdbConnector, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list(self, client: Deasy) -> None:
        response = client.vdb_connector.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vdb_connector = response.parse()
        assert_matches_type(ListVdbConnector, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list(self, client: Deasy) -> None:
        with client.vdb_connector.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vdb_connector = response.parse()
            assert_matches_type(ListVdbConnector, vdb_connector, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_delete(self, client: Deasy) -> None:
        vdb_connector = client.vdb_connector.delete(
            connector_name="connector_name",
        )
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_delete(self, client: Deasy) -> None:
        response = client.vdb_connector.with_raw_response.delete(
            connector_name="connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vdb_connector = response.parse()
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_delete(self, client: Deasy) -> None:
        with client.vdb_connector.with_streaming_response.delete(
            connector_name="connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vdb_connector = response.parse()
            assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_get_delete_stats(self, client: Deasy) -> None:
        vdb_connector = client.vdb_connector.get_delete_stats(
            connector_name="connector_name",
        )
        assert_matches_type(VdbConnectorGetDeleteStatsResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get_delete_stats(self, client: Deasy) -> None:
        response = client.vdb_connector.with_raw_response.get_delete_stats(
            connector_name="connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vdb_connector = response.parse()
        assert_matches_type(VdbConnectorGetDeleteStatsResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get_delete_stats(self, client: Deasy) -> None:
        with client.vdb_connector.with_streaming_response.get_delete_stats(
            connector_name="connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vdb_connector = response.parse()
            assert_matches_type(VdbConnectorGetDeleteStatsResponse, vdb_connector, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncVdbConnector:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncDeasy) -> None:
        vdb_connector = await async_client.vdb_connector.create(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
            },
            connector_name="connector_name",
        )
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncDeasy) -> None:
        vdb_connector = await async_client.vdb_connector.create(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
                "filename_key": "filename_key",
                "index_info": {
                    "found_indexes": ["string"],
                    "total_indexes_found": 0,
                },
                "text_key": "text_key",
                "type": "PSQLVectorDBManager",
            },
            connector_name="connector_name",
        )
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncDeasy) -> None:
        response = await async_client.vdb_connector.with_raw_response.create(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
            },
            connector_name="connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vdb_connector = await response.parse()
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncDeasy) -> None:
        async with async_client.vdb_connector.with_streaming_response.create(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
            },
            connector_name="connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vdb_connector = await response.parse()
            assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_update(self, async_client: AsyncDeasy) -> None:
        vdb_connector = await async_client.vdb_connector.update(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
            },
            connector_name="connector_name",
        )
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncDeasy) -> None:
        vdb_connector = await async_client.vdb_connector.update(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
                "filename_key": "filename_key",
                "index_info": {
                    "found_indexes": ["string"],
                    "total_indexes_found": 0,
                },
                "text_key": "text_key",
                "type": "PSQLVectorDBManager",
            },
            connector_name="connector_name",
        )
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncDeasy) -> None:
        response = await async_client.vdb_connector.with_raw_response.update(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
            },
            connector_name="connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vdb_connector = await response.parse()
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncDeasy) -> None:
        async with async_client.vdb_connector.with_streaming_response.update(
            connector_body={
                "collection_name": "collection_name",
                "database_name": "database_name",
                "db_user": "db_user",
                "name": "name",
                "password": "password",
                "port": "port",
                "url": "url",
            },
            connector_name="connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vdb_connector = await response.parse()
            assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_list(self, async_client: AsyncDeasy) -> None:
        vdb_connector = await async_client.vdb_connector.list()
        assert_matches_type(ListVdbConnector, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncDeasy) -> None:
        response = await async_client.vdb_connector.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vdb_connector = await response.parse()
        assert_matches_type(ListVdbConnector, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncDeasy) -> None:
        async with async_client.vdb_connector.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vdb_connector = await response.parse()
            assert_matches_type(ListVdbConnector, vdb_connector, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete(self, async_client: AsyncDeasy) -> None:
        vdb_connector = await async_client.vdb_connector.delete(
            connector_name="connector_name",
        )
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncDeasy) -> None:
        response = await async_client.vdb_connector.with_raw_response.delete(
            connector_name="connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vdb_connector = await response.parse()
        assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncDeasy) -> None:
        async with async_client.vdb_connector.with_streaming_response.delete(
            connector_name="connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vdb_connector = await response.parse()
            assert_matches_type(ConnectorResponse, vdb_connector, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_delete_stats(self, async_client: AsyncDeasy) -> None:
        vdb_connector = await async_client.vdb_connector.get_delete_stats(
            connector_name="connector_name",
        )
        assert_matches_type(VdbConnectorGetDeleteStatsResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get_delete_stats(self, async_client: AsyncDeasy) -> None:
        response = await async_client.vdb_connector.with_raw_response.get_delete_stats(
            connector_name="connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        vdb_connector = await response.parse()
        assert_matches_type(VdbConnectorGetDeleteStatsResponse, vdb_connector, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get_delete_stats(self, async_client: AsyncDeasy) -> None:
        async with async_client.vdb_connector.with_streaming_response.get_delete_stats(
            connector_name="connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            vdb_connector = await response.parse()
            assert_matches_type(VdbConnectorGetDeleteStatsResponse, vdb_connector, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import Required, TypeAlias, TypedDict

from .s3_connector_config_param import S3ConnectorConfigParam
from .psql_connector_config_param import PsqlConnectorConfigParam
from .qdrant_connector_config_param import QdrantConnectorConfigParam
from .sharepoint_connector_config_param import SharepointConnectorConfigParam

__all__ = ["VdbConnectorCreateParams", "ConnectorBody"]


class VdbConnectorCreateParams(TypedDict, total=False):
    connector_body: Required[ConnectorBody]

    connector_name: Required[str]


ConnectorBody: TypeAlias = Union[
    PsqlConnectorConfigParam, QdrantConnectorConfigParam, S3ConnectorConfigParam, SharepointConnectorConfigParam
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["DeasyTag"]


class DeasyTag(BaseModel):
    created_at: datetime

    description: str

    name: str

    tag_id: str

    username: str

    available_values: Optional[List[str]] = None

    date_format: Optional[str] = None

    examples: Optional[List[Union[Dict[str, object], str]]] = None

    max_values: Optional[int] = FieldInfo(alias="maxValues", default=None)

    output_type: Optional[str] = None

    tuned: Optional[int] = None

    updated_at: Optional[datetime] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["PrepareDataCreateResponse"]


class PrepareDataCreateResponse(BaseModel):
    message: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from deasy_client import Deasy, AsyncDeasy
from deasy_client.types import (
    MetadataListResponse,
    MetadataDeleteResponse,
    MetadataUpsertResponse,
    MetadataListPaginatedResponse,
    MetadataGetDistributionsResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMetadata:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_list(self, client: Deasy) -> None:
        metadata = client.metadata.list(
            data_connector_name="data_connector_name",
        )
        assert_matches_type(MetadataListResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_list_with_all_params(self, client: Deasy) -> None:
        metadata = client.metadata.list(
            data_connector_name="data_connector_name",
            conditions={
                "children": [],
                "condition": "AND",
                "tag": {
                    "name": "name",
                    "values": ["string"],
                    "operator": "operator",
                },
            },
            dataslice_id="dataslice_id",
            include_chunk_level=True,
            tag_names=["string"],
        )
        assert_matches_type(MetadataListResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list(self, client: Deasy) -> None:
        response = client.metadata.with_raw_response.list(
            data_connector_name="data_connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        metadata = response.parse()
        assert_matches_type(MetadataListResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list(self, client: Deasy) -> None:
        with client.metadata.with_streaming_response.list(
            data_connector_name="data_connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            metadata = response.parse()
            assert_matches_type(MetadataListResponse, metadata, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_delete(self, client: Deasy) -> None:
        metadata = client.metadata.delete(
            data_connector_name="data_connector_name",
        )
        assert_matches_type(MetadataDeleteResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_delete_with_all_params(self, client: Deasy) -> None:
        metadata = client.metadata.delete(
            data_connector_name="data_connector_name",
            conditions={
                "children": [],
                "condition": "AND",
                "tag": {
                    "name": "name",
                    "values": ["string"],
                    "operator": "operator",
                },
            },
            file_names=["string"],
            tags=["string"],
        )
        assert_matches_type(MetadataDeleteResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_delete(self, client: Deasy) -> None:
        response = client.metadata.with_raw_response.delete(
            data_connector_name="data_connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        metadata = response.parse()
        assert_matches_type(MetadataDeleteResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_delete(self, client: Deasy) -> None:
        with client.metadata.with_streaming_response.delete(
            data_connector_name="data_connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            metadata = response.parse()
            assert_matches_type(MetadataDeleteResponse, metadata, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_get_distributions(self, client: Deasy) -> None:
        metadata = client.metadata.get_distributions(
            data_connector_name="data_connector_name",
        )
        assert_matches_type(MetadataGetDistributionsResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_get_distributions_with_all_params(self, client: Deasy) -> None:
        metadata = client.metadata.get_distributions(
            data_connector_name="data_connector_name",
            dataslice_id="dataslice_id",
            schema_name="schema_name",
            tag_names=["string"],
        )
        assert_matches_type(MetadataGetDistributionsResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get_distributions(self, client: Deasy) -> None:
        response = client.metadata.with_raw_response.get_distributions(
            data_connector_name="data_connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        metadata = response.parse()
        assert_matches_type(MetadataGetDistributionsResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get_distributions(self, client: Deasy) -> None:
        with client.metadata.with_streaming_response.get_distributions(
            data_connector_name="data_connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            metadata = response.parse()
            assert_matches_type(MetadataGetDistributionsResponse, metadata, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_list_paginated(self, client: Deasy) -> None:
        metadata = client.metadata.list_paginated(
            data_connector_name="data_connector_name",
        )
        assert_matches_type(MetadataListPaginatedResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_list_paginated_with_all_params(self, client: Deasy) -> None:
        metadata = client.metadata.list_paginated(
            data_connector_name="data_connector_name",
            conditions={
                "children": [],
                "condition": "AND",
                "tag": {
                    "name": "name",
                    "values": ["string"],
                    "operator": "operator",
                },
            },
            dataslice_id="dataslice_id",
            include_chunk_level=True,
            limit=0,
            offset=0,
            tag_names=["string"],
        )
        assert_matches_type(MetadataListPaginatedResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list_paginated(self, client: Deasy) -> None:
        response = client.metadata.with_raw_response.list_paginated(
            data_connector_name="data_connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        metadata = response.parse()
        assert_matches_type(MetadataListPaginatedResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list_paginated(self, client: Deasy) -> None:
        with client.metadata.with_streaming_response.list_paginated(
            data_connector_name="data_connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            metadata = response.parse()
            assert_matches_type(MetadataListPaginatedResponse, metadata, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_upsert(self, client: Deasy) -> None:
        metadata = client.metadata.upsert(
            metadata={"foo": {"foo": {}}},
        )
        assert_matches_type(MetadataUpsertResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_upsert_with_all_params(self, client: Deasy) -> None:
        metadata = client.metadata.upsert(
            metadata={
                "foo": {
                    "foo": {
                        "chunk_level": {
                            "foo": {
                                "values": ["string"],
                                "evidence": "evidence",
                            }
                        },
                        "file_level": {
                            "values": ["string"],
                            "evidence": "evidence",
                        },
                    }
                }
            },
            data_connector_name="data_connector_name",
            dataslice_id="dataslice_id",
        )
        assert_matches_type(MetadataUpsertResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_upsert(self, client: Deasy) -> None:
        response = client.metadata.with_raw_response.upsert(
            metadata={"foo": {"foo": {}}},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        metadata = response.parse()
        assert_matches_type(MetadataUpsertResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_upsert(self, client: Deasy) -> None:
        with client.metadata.with_streaming_response.upsert(
            metadata={"foo": {"foo": {}}},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            metadata = response.parse()
            assert_matches_type(MetadataUpsertResponse, metadata, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncMetadata:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_list(self, async_client: AsyncDeasy) -> None:
        metadata = await async_client.metadata.list(
            data_connector_name="data_connector_name",
        )
        assert_matches_type(MetadataListResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncDeasy) -> None:
        metadata = await async_client.metadata.list(
            data_connector_name="data_connector_name",
            conditions={
                "children": [],
                "condition": "AND",
                "tag": {
                    "name": "name",
                    "values": ["string"],
                    "operator": "operator",
                },
            },
            dataslice_id="dataslice_id",
            include_chunk_level=True,
            tag_names=["string"],
        )
        assert_matches_type(MetadataListResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncDeasy) -> None:
        response = await async_client.metadata.with_raw_response.list(
            data_connector_name="data_connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        metadata = await response.parse()
        assert_matches_type(MetadataListResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncDeasy) -> None:
        async with async_client.metadata.with_streaming_response.list(
            data_connector_name="data_connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            metadata = await response.parse()
            assert_matches_type(MetadataListResponse, metadata, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete(self, async_client: AsyncDeasy) -> None:
        metadata = await async_client.metadata.delete(
            data_connector_name="data_connector_name",
        )
        assert_matches_type(MetadataDeleteResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete_with_all_params(self, async_client: AsyncDeasy) -> None:
        metadata = await async_client.metadata.delete(
            data_connector_name="data_connector_name",
            conditions={
                "children": [],
                "condition": "AND",
                "tag": {
                    "name": "name",
                    "values": ["string"],
                    "operator": "operator",
                },
            },
            file_names=["string"],
            tags=["string"],
        )
        assert_matches_type(MetadataDeleteResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncDeasy) -> None:
        response = await async_client.metadata.with_raw_response.delete(
            data_connector_name="data_connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        metadata = await response.parse()
        assert_matches_type(MetadataDeleteResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncDeasy) -> None:
        async with async_client.metadata.with_streaming_response.delete(
            data_connector_name="data_connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            metadata = await response.parse()
            assert_matches_type(MetadataDeleteResponse, metadata, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_distributions(self, async_client: AsyncDeasy) -> None:
        metadata = await async_client.metadata.get_distributions(
            data_connector_name="data_connector_name",
        )
        assert_matches_type(MetadataGetDistributionsResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_distributions_with_all_params(self, async_client: AsyncDeasy) -> None:
        metadata = await async_client.metadata.get_distributions(
            data_connector_name="data_connector_name",
            dataslice_id="dataslice_id",
            schema_name="schema_name",
            tag_names=["string"],
        )
        assert_matches_type(MetadataGetDistributionsResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get_distributions(self, async_client: AsyncDeasy) -> None:
        response = await async_client.metadata.with_raw_response.get_distributions(
            data_connector_name="data_connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        metadata = await response.parse()
        assert_matches_type(MetadataGetDistributionsResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get_distributions(self, async_client: AsyncDeasy) -> None:
        async with async_client.metadata.with_streaming_response.get_distributions(
            data_connector_name="data_connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            metadata = await response.parse()
            assert_matches_type(MetadataGetDistributionsResponse, metadata, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_paginated(self, async_client: AsyncDeasy) -> None:
        metadata = await async_client.metadata.list_paginated(
            data_connector_name="data_connector_name",
        )
        assert_matches_type(MetadataListPaginatedResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_paginated_with_all_params(self, async_client: AsyncDeasy) -> None:
        metadata = await async_client.metadata.list_paginated(
            data_connector_name="data_connector_name",
            conditions={
                "children": [],
                "condition": "AND",
                "tag": {
                    "name": "name",
                    "values": ["string"],
                    "operator": "operator",
                },
            },
            dataslice_id="dataslice_id",
            include_chunk_level=True,
            limit=0,
            offset=0,
            tag_names=["string"],
        )
        assert_matches_type(MetadataListPaginatedResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list_paginated(self, async_client: AsyncDeasy) -> None:
        response = await async_client.metadata.with_raw_response.list_paginated(
            data_connector_name="data_connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        metadata = await response.parse()
        assert_matches_type(MetadataListPaginatedResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list_paginated(self, async_client: AsyncDeasy) -> None:
        async with async_client.metadata.with_streaming_response.list_paginated(
            data_connector_name="data_connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            metadata = await response.parse()
            assert_matches_type(MetadataListPaginatedResponse, metadata, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_upsert(self, async_client: AsyncDeasy) -> None:
        metadata = await async_client.metadata.upsert(
            metadata={"foo": {"foo": {}}},
        )
        assert_matches_type(MetadataUpsertResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_upsert_with_all_params(self, async_client: AsyncDeasy) -> None:
        metadata = await async_client.metadata.upsert(
            metadata={
                "foo": {
                    "foo": {
                        "chunk_level": {
                            "foo": {
                                "values": ["string"],
                                "evidence": "evidence",
                            }
                        },
                        "file_level": {
                            "values": ["string"],
                            "evidence": "evidence",
                        },
                    }
                }
            },
            data_connector_name="data_connector_name",
            dataslice_id="dataslice_id",
        )
        assert_matches_type(MetadataUpsertResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_upsert(self, async_client: AsyncDeasy) -> None:
        response = await async_client.metadata.with_raw_response.upsert(
            metadata={"foo": {"foo": {}}},
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        metadata = await response.parse()
        assert_matches_type(MetadataUpsertResponse, metadata, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_upsert(self, async_client: AsyncDeasy) -> None:
        async with async_client.metadata.with_streaming_response.upsert(
            metadata={"foo": {"foo": {}}},
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            metadata = await response.parse()
            assert_matches_type(MetadataUpsertResponse, metadata, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["S3ConnectorConfig"]


class S3ConnectorConfig(BaseModel):
    aws_access_key_id: str

    aws_secret_access_key: str

    bucket_name: str

    name: str

    type: Optional[Literal["S3DataSourceManager"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Optional

import httpx

from .export import (
    ExportResource,
    AsyncExportResource,
    ExportResourceWithRawResponse,
    AsyncExportResourceWithRawResponse,
    ExportResourceWithStreamingResponse,
    AsyncExportResourceWithStreamingResponse,
)
from ...types import (
    dataslice_create_params,
    dataslice_delete_params,
    dataslice_get_files_params,
    dataslice_get_metrics_params,
    dataslice_get_file_count_params,
    dataslice_get_tag_vdb_distribution_params,
)
from ..._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.condition_input_param import ConditionInputParam
from ...types.dataslice_list_response import DatasliceListResponse
from ...types.dataslice_create_response import DatasliceCreateResponse
from ...types.dataslice_delete_response import DatasliceDeleteResponse
from ...types.dataslice_get_files_response import DatasliceGetFilesResponse
from ...types.dataslice_get_metrics_response import DatasliceGetMetricsResponse
from ...types.dataslice_get_file_count_response import DatasliceGetFileCountResponse
from ...types.dataslice_get_tag_vdb_distribution_response import DatasliceGetTagVdbDistributionResponse

__all__ = ["DatasliceResource", "AsyncDatasliceResource"]


class DatasliceResource(SyncAPIResource):
    @cached_property
    def export(self) -> ExportResource:
        return ExportResource(self._client)

    @cached_property
    def with_raw_response(self) -> DatasliceResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return DatasliceResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DatasliceResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return DatasliceResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        data_connector_name: str,
        dataslice_name: str,
        graph_id: str,
        latest_graph: Dict[str, object],
        condition: Optional[ConditionInputParam] | NotGiven = NOT_GIVEN,
        data_points: Optional[int] | NotGiven = NOT_GIVEN,
        description: Optional[str] | NotGiven = NOT_GIVEN,
        parent_dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        status: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DatasliceCreateResponse:
        """
        Create a new use case based on given conditions

        Attributes:

            dataslice_name: The name of the dataslice to create.
            condition: The conditions to qualify files for the dataslice.
            condition_new: The new conditions to qualify files for the dataslice.
            description: The description of the dataslice to create.
            status: The status of the dataslice to create.
            data_points: The data points to include in the dataslice.
            latest_graph: The latest graph to include in the dataslice.
            graph_id: The id of the graph to include in the dataslice.
            data_connector_name: The name of the vdb profile to include in the dataslice.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/dataslice/create",
            body=maybe_transform(
                {
                    "data_connector_name": data_connector_name,
                    "dataslice_name": dataslice_name,
                    "graph_id": graph_id,
                    "latest_graph": latest_graph,
                    "condition": condition,
                    "data_points": data_points,
                    "description": description,
                    "parent_dataslice_id": parent_dataslice_id,
                    "status": status,
                },
                dataslice_create_params.DatasliceCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasliceCreateResponse,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DatasliceListResponse:
        """List all dataslices"""
        return self._get(
            "/dataslice/list",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasliceListResponse,
        )

    def delete(
        self,
        *,
        dataslice_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DatasliceDeleteResponse:
        """
        Delete a use case

        Attributes:

            dataslice_id: The id of the dataslice to delete.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._delete(
            "/dataslice/delete",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"dataslice_id": dataslice_id}, dataslice_delete_params.DatasliceDeleteParams),
            ),
            cast_to=DatasliceDeleteResponse,
        )

    def get_file_count(
        self,
        *,
        data_connector_name: str,
        condition: Optional[ConditionInputParam] | NotGiven = NOT_GIVEN,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DatasliceGetFileCountResponse:
        """
        Get count of files matching dataslice conditions or provided conditions

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/dataslice/file_count",
            body=maybe_transform(
                {
                    "data_connector_name": data_connector_name,
                    "condition": condition,
                    "dataslice_id": dataslice_id,
                },
                dataslice_get_file_count_params.DatasliceGetFileCountParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasliceGetFileCountResponse,
        )

    def get_files(
        self,
        *,
        dataslice_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DatasliceGetFilesResponse:
        """
        Get all files associated with a dataslice

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/dataslice/files",
            body=maybe_transform({"dataslice_id": dataslice_id}, dataslice_get_files_params.DatasliceGetFilesParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasliceGetFilesResponse,
        )

    def get_metrics(
        self,
        *,
        data_connector_name: Optional[str] | NotGiven = NOT_GIVEN,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        file_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        node_ids: Optional[List[str]] | NotGiven = NOT_GIVEN,
        tags: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DatasliceGetMetricsResponse:
        """
        Retrieve use case metrics

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/dataslice/metrics",
            body=maybe_transform(
                {
                    "data_connector_name": data_connector_name,
                    "dataslice_id": dataslice_id,
                    "file_names": file_names,
                    "node_ids": node_ids,
                    "tags": tags,
                },
                dataslice_get_metrics_params.DatasliceGetMetricsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasliceGetMetricsResponse,
        )

    def get_tag_vdb_distribution(
        self,
        *,
        data_connector_name: Optional[str] | NotGiven = NOT_GIVEN,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DatasliceGetTagVdbDistributionResponse:
        """
        Get the distribution of tags in a dataslice

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/dataslice/tag_vdb_distribution",
            body=maybe_transform(
                {
                    "data_connector_name": data_connector_name,
                    "dataslice_id": dataslice_id,
                },
                dataslice_get_tag_vdb_distribution_params.DatasliceGetTagVdbDistributionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasliceGetTagVdbDistributionResponse,
        )


class AsyncDatasliceResource(AsyncAPIResource):
    @cached_property
    def export(self) -> AsyncExportResource:
        return AsyncExportResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncDatasliceResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#accessing-raw-response-data-eg-headers
        """
        return AsyncDatasliceResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDatasliceResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-labs#with_streaming_response
        """
        return AsyncDatasliceResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        data_connector_name: str,
        dataslice_name: str,
        graph_id: str,
        latest_graph: Dict[str, object],
        condition: Optional[ConditionInputParam] | NotGiven = NOT_GIVEN,
        data_points: Optional[int] | NotGiven = NOT_GIVEN,
        description: Optional[str] | NotGiven = NOT_GIVEN,
        parent_dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        status: str | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DatasliceCreateResponse:
        """
        Create a new use case based on given conditions

        Attributes:

            dataslice_name: The name of the dataslice to create.
            condition: The conditions to qualify files for the dataslice.
            condition_new: The new conditions to qualify files for the dataslice.
            description: The description of the dataslice to create.
            status: The status of the dataslice to create.
            data_points: The data points to include in the dataslice.
            latest_graph: The latest graph to include in the dataslice.
            graph_id: The id of the graph to include in the dataslice.
            data_connector_name: The name of the vdb profile to include in the dataslice.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/dataslice/create",
            body=await async_maybe_transform(
                {
                    "data_connector_name": data_connector_name,
                    "dataslice_name": dataslice_name,
                    "graph_id": graph_id,
                    "latest_graph": latest_graph,
                    "condition": condition,
                    "data_points": data_points,
                    "description": description,
                    "parent_dataslice_id": parent_dataslice_id,
                    "status": status,
                },
                dataslice_create_params.DatasliceCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasliceCreateResponse,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DatasliceListResponse:
        """List all dataslices"""
        return await self._get(
            "/dataslice/list",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasliceListResponse,
        )

    async def delete(
        self,
        *,
        dataslice_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DatasliceDeleteResponse:
        """
        Delete a use case

        Attributes:

            dataslice_id: The id of the dataslice to delete.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._delete(
            "/dataslice/delete",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"dataslice_id": dataslice_id}, dataslice_delete_params.DatasliceDeleteParams
                ),
            ),
            cast_to=DatasliceDeleteResponse,
        )

    async def get_file_count(
        self,
        *,
        data_connector_name: str,
        condition: Optional[ConditionInputParam] | NotGiven = NOT_GIVEN,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DatasliceGetFileCountResponse:
        """
        Get count of files matching dataslice conditions or provided conditions

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/dataslice/file_count",
            body=await async_maybe_transform(
                {
                    "data_connector_name": data_connector_name,
                    "condition": condition,
                    "dataslice_id": dataslice_id,
                },
                dataslice_get_file_count_params.DatasliceGetFileCountParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasliceGetFileCountResponse,
        )

    async def get_files(
        self,
        *,
        dataslice_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DatasliceGetFilesResponse:
        """
        Get all files associated with a dataslice

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/dataslice/files",
            body=await async_maybe_transform(
                {"dataslice_id": dataslice_id}, dataslice_get_files_params.DatasliceGetFilesParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasliceGetFilesResponse,
        )

    async def get_metrics(
        self,
        *,
        data_connector_name: Optional[str] | NotGiven = NOT_GIVEN,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        file_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        node_ids: Optional[List[str]] | NotGiven = NOT_GIVEN,
        tags: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DatasliceGetMetricsResponse:
        """
        Retrieve use case metrics

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/dataslice/metrics",
            body=await async_maybe_transform(
                {
                    "data_connector_name": data_connector_name,
                    "dataslice_id": dataslice_id,
                    "file_names": file_names,
                    "node_ids": node_ids,
                    "tags": tags,
                },
                dataslice_get_metrics_params.DatasliceGetMetricsParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasliceGetMetricsResponse,
        )

    async def get_tag_vdb_distribution(
        self,
        *,
        data_connector_name: Optional[str] | NotGiven = NOT_GIVEN,
        dataslice_id: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> DatasliceGetTagVdbDistributionResponse:
        """
        Get the distribution of tags in a dataslice

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/dataslice/tag_vdb_distribution",
            body=await async_maybe_transform(
                {
                    "data_connector_name": data_connector_name,
                    "dataslice_id": dataslice_id,
                },
                dataslice_get_tag_vdb_distribution_params.DatasliceGetTagVdbDistributionParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=DatasliceGetTagVdbDistributionResponse,
        )


class DatasliceResourceWithRawResponse:
    def __init__(self, dataslice: DatasliceResource) -> None:
        self._dataslice = dataslice

        self.create = to_raw_response_wrapper(
            dataslice.create,
        )
        self.list = to_raw_response_wrapper(
            dataslice.list,
        )
        self.delete = to_raw_response_wrapper(
            dataslice.delete,
        )
        self.get_file_count = to_raw_response_wrapper(
            dataslice.get_file_count,
        )
        self.get_files = to_raw_response_wrapper(
            dataslice.get_files,
        )
        self.get_metrics = to_raw_response_wrapper(
            dataslice.get_metrics,
        )
        self.get_tag_vdb_distribution = to_raw_response_wrapper(
            dataslice.get_tag_vdb_distribution,
        )

    @cached_property
    def export(self) -> ExportResourceWithRawResponse:
        return ExportResourceWithRawResponse(self._dataslice.export)


class AsyncDatasliceResourceWithRawResponse:
    def __init__(self, dataslice: AsyncDatasliceResource) -> None:
        self._dataslice = dataslice

        self.create = async_to_raw_response_wrapper(
            dataslice.create,
        )
        self.list = async_to_raw_response_wrapper(
            dataslice.list,
        )
        self.delete = async_to_raw_response_wrapper(
            dataslice.delete,
        )
        self.get_file_count = async_to_raw_response_wrapper(
            dataslice.get_file_count,
        )
        self.get_files = async_to_raw_response_wrapper(
            dataslice.get_files,
        )
        self.get_metrics = async_to_raw_response_wrapper(
            dataslice.get_metrics,
        )
        self.get_tag_vdb_distribution = async_to_raw_response_wrapper(
            dataslice.get_tag_vdb_distribution,
        )

    @cached_property
    def export(self) -> AsyncExportResourceWithRawResponse:
        return AsyncExportResourceWithRawResponse(self._dataslice.export)


class DatasliceResourceWithStreamingResponse:
    def __init__(self, dataslice: DatasliceResource) -> None:
        self._dataslice = dataslice

        self.create = to_streamed_response_wrapper(
            dataslice.create,
        )
        self.list = to_streamed_response_wrapper(
            dataslice.list,
        )
        self.delete = to_streamed_response_wrapper(
            dataslice.delete,
        )
        self.get_file_count = to_streamed_response_wrapper(
            dataslice.get_file_count,
        )
        self.get_files = to_streamed_response_wrapper(
            dataslice.get_files,
        )
        self.get_metrics = to_streamed_response_wrapper(
            dataslice.get_metrics,
        )
        self.get_tag_vdb_distribution = to_streamed_response_wrapper(
            dataslice.get_tag_vdb_distribution,
        )

    @cached_property
    def export(self) -> ExportResourceWithStreamingResponse:
        return ExportResourceWithStreamingResponse(self._dataslice.export)


class AsyncDatasliceResourceWithStreamingResponse:
    def __init__(self, dataslice: AsyncDatasliceResource) -> None:
        self._dataslice = dataslice

        self.create = async_to_streamed_response_wrapper(
            dataslice.create,
        )
        self.list = async_to_streamed_response_wrapper(
            dataslice.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            dataslice.delete,
        )
        self.get_file_count = async_to_streamed_response_wrapper(
            dataslice.get_file_count,
        )
        self.get_files = async_to_streamed_response_wrapper(
            dataslice.get_files,
        )
        self.get_metrics = async_to_streamed_response_wrapper(
            dataslice.get_metrics,
        )
        self.get_tag_vdb_distribution = async_to_streamed_response_wrapper(
            dataslice.get_tag_vdb_distribution,
        )

    @cached_property
    def export(self) -> AsyncExportResourceWithStreamingResponse:
        return AsyncExportResourceWithStreamingResponse(self._dataslice.export)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Optional
from typing_extensions import Required, TypedDict

__all__ = ["DatasliceCreateParams"]


class DatasliceCreateParams(TypedDict, total=False):
    data_connector_name: Required[str]

    dataslice_name: Required[str]

    graph_id: Required[str]

    latest_graph: Required[Dict[str, object]]

    condition: Optional["ConditionInputParam"]

    data_points: Optional[int]

    description: Optional[str]

    parent_dataslice_id: Optional[str]

    status: str


from .condition_input_param import ConditionInputParam



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from .openai_config_param import OpenAIConfigParam

__all__ = ["LlmConnectorCreateParams"]


class LlmConnectorCreateParams(TypedDict, total=False):
    connector_body: Required[OpenAIConfigParam]

    connector_name: Required[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Optional
from typing_extensions import Required, TypedDict

__all__ = [
    "MetadataUpsertParams",
    "MetadataMetadataItem",
    "MetadataMetadataItemChunkLevel",
    "MetadataMetadataItemFileLevel",
]


class MetadataUpsertParams(TypedDict, total=False):
    metadata: Required[Dict[str, Dict[str, MetadataMetadataItem]]]

    data_connector_name: Optional[str]

    dataslice_id: Optional[str]


class MetadataMetadataItemChunkLevel(TypedDict, total=False):
    values: Required[List[str]]

    evidence: Optional[str]


class MetadataMetadataItemFileLevel(TypedDict, total=False):
    values: Required[List[str]]

    evidence: Optional[str]


class MetadataMetadataItem(TypedDict, total=False):
    chunk_level: Optional[Dict[str, Optional[MetadataMetadataItemChunkLevel]]]

    file_level: Optional[MetadataMetadataItemFileLevel]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import TypedDict

__all__ = ["DatasliceGetMetricsParams"]


class DatasliceGetMetricsParams(TypedDict, total=False):
    data_connector_name: Optional[str]

    dataslice_id: Optional[str]

    file_names: Optional[List[str]]

    node_ids: Optional[List[str]]

    tags: Optional[List[str]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from deasy_client import Deasy, AsyncDeasy
from deasy_client.types import SuggestSchemaCreateResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSuggestSchema:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: Deasy) -> None:
        suggest_schema = client.suggest_schema.create(
            data_connector_name="data_connector_name",
        )
        assert_matches_type(SuggestSchemaCreateResponse, suggest_schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: Deasy) -> None:
        suggest_schema = client.suggest_schema.create(
            data_connector_name="data_connector_name",
            condition={
                "children": [],
                "condition": "AND",
                "tag": {
                    "name": "name",
                    "values": ["string"],
                    "operator": "operator",
                },
            },
            context_level="context_level",
            current_tree={"foo": "bar"},
            dataslice_id="dataslice_id",
            file_names=["string"],
            graph_tag_type="open_ended",
            llm_profile_name="llm_profile_name",
            max_height=0,
            max_tags_per_level=0,
            min_tags_per_level=0,
            node={"foo": "bar"},
            progress_tracking_id="progress_tracking_id",
            schema_name="schema_name",
            set_max_values=True,
            use_existing_tags=True,
            use_extracted_tags=True,
            user_context="user_context",
            values_per_tag=0,
        )
        assert_matches_type(SuggestSchemaCreateResponse, suggest_schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: Deasy) -> None:
        response = client.suggest_schema.with_raw_response.create(
            data_connector_name="data_connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        suggest_schema = response.parse()
        assert_matches_type(SuggestSchemaCreateResponse, suggest_schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: Deasy) -> None:
        with client.suggest_schema.with_streaming_response.create(
            data_connector_name="data_connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            suggest_schema = response.parse()
            assert_matches_type(SuggestSchemaCreateResponse, suggest_schema, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncSuggestSchema:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncDeasy) -> None:
        suggest_schema = await async_client.suggest_schema.create(
            data_connector_name="data_connector_name",
        )
        assert_matches_type(SuggestSchemaCreateResponse, suggest_schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncDeasy) -> None:
        suggest_schema = await async_client.suggest_schema.create(
            data_connector_name="data_connector_name",
            condition={
                "children": [],
                "condition": "AND",
                "tag": {
                    "name": "name",
                    "values": ["string"],
                    "operator": "operator",
                },
            },
            context_level="context_level",
            current_tree={"foo": "bar"},
            dataslice_id="dataslice_id",
            file_names=["string"],
            graph_tag_type="open_ended",
            llm_profile_name="llm_profile_name",
            max_height=0,
            max_tags_per_level=0,
            min_tags_per_level=0,
            node={"foo": "bar"},
            progress_tracking_id="progress_tracking_id",
            schema_name="schema_name",
            set_max_values=True,
            use_existing_tags=True,
            use_extracted_tags=True,
            user_context="user_context",
            values_per_tag=0,
        )
        assert_matches_type(SuggestSchemaCreateResponse, suggest_schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncDeasy) -> None:
        response = await async_client.suggest_schema.with_raw_response.create(
            data_connector_name="data_connector_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        suggest_schema = await response.parse()
        assert_matches_type(SuggestSchemaCreateResponse, suggest_schema, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncDeasy) -> None:
        async with async_client.suggest_schema.with_streaming_response.create(
            data_connector_name="data_connector_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            suggest_schema = await response.parse()
            assert_matches_type(SuggestSchemaCreateResponse, suggest_schema, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, TypedDict

__all__ = ["DatasliceGetFileCountParams"]


class DatasliceGetFileCountParams(TypedDict, total=False):
    data_connector_name: Required[str]

    condition: Optional["ConditionInputParam"]

    dataslice_id: Optional[str]


from .condition_input_param import ConditionInputParam
